@@ -35,9 +35,3 @@ class BinaryTreeSearch:
                 return self.binarySearch(sortedList, search_input)
 
             return sortedList
-
-
-myList = [3, [8, [5, None, 11], 94], [7, 15, 29]]
-tree = BinaryTreeSearch()
-newList = tree.binarySearch(myList, 9)
-print(newList)
